summaryrefslogtreecommitdiffstats
path: root/src/drivers/wifi
diff options
context:
space:
mode:
authorTim Wawrzynczak <twawrzynczak@chromium.org>2022-02-23 10:17:21 -0700
committerTim Wawrzynczak <twawrzynczak@chromium.org>2022-03-03 20:46:13 +0000
commitafaee235fa0b35ac7272c3dab3a74d272bc1bd8c (patch)
treec4f4ad1733ccebfb4d84b3bf3642e0c1a3a0a4db /src/drivers/wifi
parent114d650fced9ef632aadde90bd7c8e7d1214426a (diff)
downloadcoreboot-afaee235fa0b35ac7272c3dab3a74d272bc1bd8c.tar.gz
coreboot-afaee235fa0b35ac7272c3dab3a74d272bc1bd8c.tar.bz2
coreboot-afaee235fa0b35ac7272c3dab3a74d272bc1bd8c.zip
drivers/{pcie,wifi}/generic: Update untrusted property name
In order to align with established standards for establishing DMA boundaries[1] from ACPI, the UntrustedDevice property has been renamed to DmaProperty, which follows Microsoft's implementation. After discussions with Microsoft, they have agreed to make the `UID` property optional, so it is left out here, and instead it can be applied to: 1) Internal PCI devices 2) PCIe root ports 3) Downstream PCI(e) devices [1]: https://docs.microsoft.com/en-us/windows-hardware/drivers/pci/dsd-for-pcie-root-ports BUG=b:215424986 Signed-off-by: Tim Wawrzynczak <twawrzynczak@chromium.org> Change-Id: Id70e916532e3d3d70305fc61473da28c702fc397 Reviewed-on: https://review.coreboot.org/c/coreboot/+/62435 Tested-by: build bot (Jenkins) <no-reply@coreboot.org> Reviewed-by: EricR Lai <ericr_lai@compal.corp-partner.google.com>
Diffstat (limited to 'src/drivers/wifi')
-rw-r--r--src/drivers/wifi/generic/acpi.c4
-rw-r--r--src/drivers/wifi/generic/chip.h2
2 files changed, 3 insertions, 3 deletions
diff --git a/src/drivers/wifi/generic/chip.h b/src/drivers/wifi/generic/chip.h
index 35726f217134..907b260fa3cf 100644
--- a/src/drivers/wifi/generic/chip.h
+++ b/src/drivers/wifi/generic/chip.h
@@ -10,7 +10,7 @@
struct drivers_wifi_generic_config {
unsigned int wake;
/* When set to true, this will add a _DSD which contains a single
- property, `UntrustedDevice`, set to 1, to the ACPI Device. */
+ property, `DmaProperty`, set to 1, under the ACPI Device. */
bool is_untrusted;
};
diff --git a/src/drivers/wifi/generic/acpi.c b/src/drivers/wifi/generic/acpi.c
index 7c606f9099ff..16c1839c2394 100644
--- a/src/drivers/wifi/generic/acpi.c
+++ b/src/drivers/wifi/generic/acpi.c
@@ -515,13 +515,13 @@ static void wifi_ssdt_write_properties(const struct device *dev, const char *sco
/* Wake capabilities */
acpigen_write_PRW(config->wake, ACPI_S3);
/* Add _DSD for UntrustedDevice property. */
if (config->is_untrusted) {
struct acpi_dp *dsd, *pkg;
dsd = acpi_dp_new_table("_DSD");
pkg = acpi_dp_new_table(ACPI_DSD_UNTRUSTED_UUID);
- acpi_dp_add_integer(pkg, "UntrustedDevice", 1);
+ acpi_dp_add_integer(pkg, "DmaProperty", 1);
acpi_dp_add_package(dsd, pkg);
acpi_dp_write(dsd);
}
@@ -515,13 +515,13 @@ static void wifi_ssdt_write_properties(const struct device *dev, const char *sco
/* Wake capabilities */
acpigen_write_PRW(config->wake, ACPI_S3);
- /* Add _DSD for UntrustedDevice property. */
+ /* Add _DSD for DmaProperty property. */
if (config->is_untrusted) {
struct acpi_dp *dsd, *pkg;